@@ -28,15 +28,11 @@ imports = {
 }
 
 
-__all__ = []
-
-
 def do_imports(definitions, ignore_import_error=False):
     for name, mapping in definitions.items():
         try:
             for package, import_as in mapping.items():
                 globals()[import_as] = importlib.import_module(package)
-                __all__.append(import_as)
         except ImportError:
             if ignore_import_error:
                 warnings.warn('{} is not installed and won\'t be available.'.format(name))
@@ -44,3 +40,13 @@ def do_imports(definitions, ignore_import_error=False):
 
 do_imports(imports['mandatory'], ignore_import_error=False)
 do_imports(imports['optional'], ignore_import_error=True)
+
+
+# Setting __all__ explicitly is nasty but required as auto-completion will otherwise not recognize imports.
+# In case of PyCharm, might be related to https://youtrack.jetbrains.com/issue/PY-8307.
+__all__ = [
+    'torch', 'nn', 'F', 'optim',  # torch
+    'tv', 'transforms',  # torchvision
+    'tt',  # torchtext
+    'np', 'pd'  # others
+]
\ No newline at end of file
